@@ -5,7 +5,7 @@ pggui::pggui(QWidget *parent)
     : QWidget(parent)
 {
     gpgText = new QTextEdit;
-    gpgRunButton = new QPushButton(tr("Run GPG"));
+    pgguiAboutButton = new QPushButton(tr("About"));
     gpgEncryptButton = new QPushButton(tr("Encryption"));
     gpgDecryptButton = new QPushButton(tr("Decryption"));
     gpgKeyManagmentButton = new QPushButton(tr("Key Managemnt"));
@@ -16,7 +16,7 @@ pggui::pggui(QWidget *parent)
     ButtonLayout1->addWidget(gpgEncryptButton);
     ButtonLayout1->addWidget(gpgDecryptButton);
     ButtonLayout1->addWidget(gpgKeyManagmentButton);
-    ButtonLayout1->addWidget(gpgRunButton);
+    ButtonLayout1->addWidget(pgguiAboutButton);
 
     QVBoxLayout *mainLayout = new QVBoxLayout;
     mainLayout->addWidget(gpgText);
@@ -93,7 +93,7 @@ pggui::pggui(QWidget *parent)
 
    gpg = new QProcess;
 
-   connect(gpgRunButton,SIGNAL(clicked()),this,SLOT(gpgRun()));
+   connect(pgguiAboutButton,SIGNAL(clicked()),this,SLOT(pgguiAbout()));
    connect(gpg,SIGNAL(readyReadStandardOutput()),this,SLOT(slotStringReceived())); //Receive output
    connect(gpg,SIGNAL(readyReadStandardError()),this,SLOT(slotErrorStringReceived())); //Receive Errors
    connect(gpgEncryptButton,SIGNAL(clicked()),this,SLOT(gpgEncryption()));
@@ -102,36 +102,51 @@ pggui::pggui(QWidget *parent)
    connect(gpgImportKeysButton,SIGNAL(clicked()),this,SLOT(gpgImportKey()));
 
 
+
    QTextCodec::setCodecForCStrings( QTextCodec::codecForName( "UTF-8" ) ); //general Text-Coding, needed for "Umlaute"
    QTextCodec::setCodecForLocale( QTextCodec::codecForName("UTF-8") );
    QTextCodec::setCodecForTr( QTextCodec::codecForName("UTF-8") );
 
+   //check,wether pggui has been set up
+   #ifdef Q_WS_MAEMO_5
+       QFile conf("/home/user/.gnupg-pggui/conf.txt");
+
+       if (!conf.exists()) {
+       system("mkdir /home/user/.gnupg-pggui");
+       system("touch /home/user/.gnupg-pggui/conf.txt");
+       system("chmod 0700 /home/user/.gnupg-pggui");
+       system("chmod 0644 /home/user/.gnupg-pggui/conf.txt");
+
+
+       qDebug() <<"Config-Directory created and conf file touched" ;
+
+        QMaemo5InformationBox::information(this, "<b>First start<b> \n Pggui directory created",
+                                           QMaemo5InformationBox::DefaultTimeout);
+
+
+   }
+
+   #endif
+
 
 }
 
-void pggui::gpgRun()
+void pggui::pgguiAbout()
 {
-    qDebug("Starting gpg --help");
-    gpgText->clear();
-    QString program = "gpg";
-    QStringList arguments;
+    QDialog *about = new QDialog(this);
 
-    arguments << "--help";
-
-#ifdef Q_WS_MAEMO_5
-    arguments << "--homedir" << "/home/user/.gnupg-pggui" << "--help";
-
-#endif
-
-#ifndef Q_WS_MAEMO_5
-    arguments << "--help";
-#endif
+    QLabel *aboutText = new QLabel(tr(" Private Guard Graphical User Interface \n created by Florian Brandes. For more information \n please visit https://garage.maemo.org/projects/pggui \n"));
+    aboutText->setAlignment(Qt::AlignCenter);
 
 
-    qDebug() << "Command: " << program << arguments ;
-    qDebug() << "Starting now";
+    QHBoxLayout *layout = new QHBoxLayout;
+    layout->addWidget(aboutText);
+
+
+    about->setLayout(layout);
+
+    about->show();
 
-    gpg->start(program, arguments);
 
 
 
@@ -145,6 +160,37 @@ void pggui::slotStringReceived()
 
     *strLine = QString(gpg->readAllStandardOutput());
 
+//    if (strLine->contains("Content-Type: multipart/signed")) {
+//        QString message;
+//        QString signature;
+//        int bound;
+//        int bound_up;
+//        int bound_down;
+//        int bound_last;
+//        QString boundary;
+//        bound = strLine->indexOf("boundary=");
+//        bound = bound + 10;
+//        boundary = strLine->mid(bound,22);
+
+//        qDebug() << "count: " << strLine->count(boundary);
+
+//        qDebug () << "Boundary at: " << bound;
+//        qDebug() << "Boundary string: " << boundary;
+
+//        bound_up = strLine->indexOf(boundary,bound + 1);
+//        bound_down = strLine->indexOf(boundary,bound_up +1);
+//        bound_last = strLine->indexOf(boundary,bound_down + 1);
+
+
+//        message = strLine->mid(bound_up + 22,bound_down - bound_up - 24);
+//        signature = strLine->mid(bound_down + 22, bound_last - bound_down - 24);
+
+
+//        qDebug() << "decode: " << message;
+//        qDebug() << "Signature: " << signature;
+//    }
+
+
 
     //check if encoded message has been encoded in Base64
     if (strLine->contains("Content-Transfer-Encoding: base64")) {
@@ -197,29 +243,26 @@ void pggui::gpgEncryption()
 void pggui::gpgDecryption()
 {
 
-//check,wether pggui has been set up
-#ifdef Q_WS_MAEMO_5
-    QFile conf("/home/user/.gnupg-pggui/conf.txt");
-
-    if (!conf.exists()) {
-    system("mkdir /home/user/.gnupg-pggui");
-    system("touch /home/user/.gnupg-pggui/conf.txt");
-    system("chmod 0700 /home/user/.gnupg-pggui");
-    system("chmod 0644 /home/user/.gnupg-pggui/conf.txt");
-    system("chmod 0644 /home/user/.gnupg-pggui/pubring.gpg");
-    system("chmod 0644 /home/user/.gnupg-pggui/pubring.gpg~");
-    system("chmod 0600 /home/user/.gnupg-pggui/secring.gpg");
-    system("chmod 0644 /home/user/.gnupg-pggui/trustdb.gpg");
-    system("chmod 0600 /home/user/.gnupg-pggui/random_seed");
-
-    qDebug() <<"Config-Directory created and conf file touched" ;
-        }
-#endif
-
     gpgText->clear();
 
 
     qDebug() << "GPG Decryptionslot started...";
+
+    QFile secring("/home/user/.gnupg-pggui/secring.gpg");
+
+    if (!secring.exists()) {
+        QMessageBox::information(this,tr("No private key available"),tr("No private key has been imported. Please do so in order to decrypt messeages. Keys can be imported under \"Key Managmement\" -> \"Import Keys\""));
+        return;
+        qDebug() << "No keyfile";
+    }
+
+    if (secring.size() == 0) {
+        QMessageBox::information(this,tr("No private key available"),tr("No private key has been imported. Please do so in order to decrypt messeages. Keys can be imported under \"Key Managmement\" -> \"Import Keys\""));
+        return;
+        qDebug() << "No keys in file";
+    }
+
+
     qDebug() <<"Choose File to decrypt...";
 
     QString fileName;
@@ -230,7 +273,7 @@ void pggui::gpgDecryption()
     qDebug() << "Filename: " << fileName;
 
     if (fileName.isEmpty()) {
-        QMessageBox::information(this,tr("No File selected!"),tr("No file has been selected! \n Please coose a file next time"));
+        QMessageBox::information(this,tr(" No File selected!"),tr("No file has been selected! \n Please choose a file next time"));
         qDebug() << "No File selected";
         return;
     }
@@ -334,7 +377,7 @@ void pggui::gpgImportKey()
     qDebug() << "Filename: " << fileName;
 
     if (fileName.isEmpty()) {
-        QMessageBox::information(this,tr("No Keyfile selected!"),tr("No file has been selected! \n Please coose a file next time"));
+        QMessageBox::information(this,tr("No Keyfile selected!"),tr(" No file has been selected! \n Please choose a file next time"));
         qDebug() << "No Key for import selected";
         return;
     }
@@ -363,8 +406,25 @@ void pggui::gpgImportKey()
 
     qDebug() << "Done";
 
+    QFile test("/home/user/.gnupg-pggui/secring");
+
+    if (test.exists() && test.size() > 1) {
+
+#ifdef Q_WS_MAEMO_5
+        QMaemo5InformationBox::information(this,tr("Keys successfully imported"),QMaemo5InformationBox::DefaultTimeout);
+#endif
+    }
+
+    system("chmod 0644 /home/user/.gnupg-pggui/pubring.gpg");
+    system("chmod 0644 /home/user/.gnupg-pggui/pubring.gpg~");
+    system("chmod 0600 /home/user/.gnupg-pggui/secring.gpg");
+    system("chmod 0644 /home/user/.gnupg-pggui/trustdb.gpg");
+    system("chmod 0600 /home/user/.gnupg-pggui/random_seed");
+
     KeyManagmentWindow->close();
 
+
+
 }
 
 pggui::~pggui()
