@@ -6,7 +6,9 @@
 
 #include<QProcess>
 #include<QDebug>
-
+ #ifdef Q_WS_MAEMO_5
+    #include <QMaemo5InformationBox>
+#endif
 #include "passworddialog.h"
 
 
@@ -26,7 +28,7 @@ public:
     ~pggui();
 
 public slots:
-    void gpgRun();
+    void pgguiAbout();
     void slotStringReceived();
     void slotErrorStringReceived();
     void gpgDecryption();
@@ -46,7 +48,7 @@ private:
     QMainWindow *KeyManagmentWindow;
     QMainWindow *gpgEnterKeyWindow;
 
-    QPushButton *gpgRunButton;
+    QPushButton *pgguiAboutButton;
     QPushButton *gpgEncryptButton;
     QPushButton *gpgDecryptButton;
     QPushButton *gpgKeyManagmentButton;
